@@ -1007,7 +1007,9 @@ class Script(default.Script):
 
         caretOffset = 0
         if not oldFocus or self.utilities.inFindToolbar(oldFocus):
-            newFocus, caretOffset = self.utilities.getCaretContext()
+            contextObj, contextOffset = self.utilities.getCaretContext()
+            if contextObj and not self.utilities.isZombie(contextObj):
+                newFocus, caretOffset = contextObj, contextOffset
 
         if newFocus.getRole() == pyatspi.ROLE_UNKNOWN:
             msg = "WEB: Event source has bogus role. Likely browser bug."
@@ -1170,6 +1172,9 @@ class Script(default.Script):
             msg = "WEB: Not doing SayAll due to focusable context obj %s" % obj
             debug.println(debug.LEVEL_INFO, msg, True)
             speech.speak(self.speechGenerator.generateSpeech(obj))
+        elif self.utilities.documentFragment(event.source):
+            msg = "WEB: Not doing SayAll due to page fragment"
+            debug.println(debug.LEVEL_INFO, msg, True)
         elif not _settingsManager.getSetting('sayAllOnLoad'):
             msg = "WEB: Not doing SayAll due to sayAllOnLoad being False"
             debug.println(debug.LEVEL_INFO, msg, True)
@@ -1279,7 +1284,11 @@ class Script(default.Script):
             return True
 
         char = text.getText(event.detail1, event.detail1+1)
-        isEditable = obj.getState().contains(pyatspi.STATE_EDITABLE)
+        try:
+            isEditable = obj.getState().contains(pyatspi.STATE_EDITABLE)
+        except:
+            isEditable = False
+
         if not char and not isEditable:
             msg = "WEB: Event ignored: Was for empty char in non-editable text"
             debug.println(debug.LEVEL_INFO, msg, True)
@@ -1399,7 +1408,12 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             return True
 
-        obj, offset = self.utilities.getCaretContext()
+        obj, offset = self.utilities.getCaretContext(getZombieReplicant=False)
+        if self.utilities.isZombie(obj):
+            obj, offset = self.utilities.getCaretContext(getZombieReplicant=True)
+            if obj and self.utilities.isZombie(orca_state.locusOfFocus):
+                orca.setLocusOfFocus(event, obj, notifyScript=False)
+
         contextDocument = self.utilities.getDocumentForObject(obj)
         if obj and document == contextDocument and self.utilities.isZombie(obj):
             msg = "WEB: Context obj %s is Zombie." % obj
@@ -1555,6 +1569,8 @@ class Script(default.Script):
             cause = "Context is not a non-focused link"
         elif self.utilities.isChildOfCurrentFragment(obj):
             cause = "Context is child of current fragment"
+        elif document == event.source and self.utilities.documentFragment(event.source):
+            cause = "Document URI is fragment"
         else:
             return False
 
@@ -1828,7 +1844,8 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             return False
 
-        char = text.getText(event.detail1, event.detail1+1)
+        offset = text.caretOffset
+        char = text.getText(offset, offset+1)
         if char == self.EMBEDDED_OBJECT_CHARACTER \
            and not self.utilities.lastInputEventWasCaretNavWithSelection() \
            and not self.utilities.lastInputEventWasCommand():
